quiesce: use entry id for interface

Extension code does not have the Entry object as an input parameter. The
quiesce interface should not require an Entry object. Refactor the code
a bit to allow for this.

Signed-off-by: Andrew Geissler <geissonator@yahoo.com>
Change-Id: I5caee881dae3d6c22f4f619af5acd3e3e33379aa
diff --git a/log_manager.hpp b/log_manager.hpp
index 34117dc..be8c8b4 100644
--- a/log_manager.hpp
+++ b/log_manager.hpp
@@ -196,11 +196,11 @@
      */
     bool isQuiesceOnErrorEnabled();
 
-    /** @brief Check if error has callout and if so, block boot
+    /** @brief Create boot block association and quiesce host if running
      *
      * @param[in] entry - The error to check for callouts
      */
-    void checkQuiesceOnError(const Entry& entry);
+    void quiesceOnError(const uint32_t entryId);
 
     /** @brief Check if inventory callout present in input entry
      *
@@ -196,11 +196,11 @@
      *
-     * @param[in] entry - The error to check for callouts
+     * @param[in] entryId - The ID of the phosphor logging error
      */